"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isUseState = exports.isUseRef = exports.isUseSomething = exports.isReactText = exports.startsWithIgnoreCase = exports.compareIgnoreCase = exports.relativePathContainNodeModules = exports.getPackageNameOrNamespaceInNodeModules = exports.first = exports.assertDef = exports.isDef = void 0;
const path = require("path");
const constants_1 = require("./constants");
function isDef(v) {
    return v !== undefined && v !== null;
}
exports.isDef = isDef;
function assertDef(v) {
    if (!isDef(v)) {
        throw new Error('Must be defined');
    }
}
exports.assertDef = assertDef;
function first(v) {
    if (v.length === 0) {
        throw new Error('Index out of range');
    }
    return v[0];
}
exports.first = first;
function getPackageNameOrNamespaceInNodeModules(filename) {
    if (!filename.includes(constants_1.Constants.NodeModules)) {
        return undefined;
    }
    const paths = filename.split(path.sep);
    const firstNodeModulesIndex = paths.indexOf(constants_1.Constants.NodeModules);
    const packageNames = paths.slice(firstNodeModulesIndex + 1);
    const [nameOrNamespace, maybeName] = packageNames;
    if (nameOrNamespace &&
        maybeName &&
        nameOrNamespace.startsWith(constants_1.Constants.NamespacePrefix)) {
        return [nameOrNamespace, maybeName].join(path.sep);
    }
    return nameOrNamespace;
}
exports.getPackageNameOrNamespaceInNodeModules = getPackageNameOrNamespaceInNodeModules;
function relativePathContainNodeModules(from, to) {
    return path.relative(from, to).includes(constants_1.Constants.NodeModules);
}
exports.relativePathContainNodeModules = relativePathContainNodeModules;
function compareIgnoreCase(a, b) {
    return a.toLowerCase() === b.toLowerCase();
}
exports.compareIgnoreCase = compareIgnoreCase;
function startsWithIgnoreCase(a, b) {
    return a.toLowerCase().startsWith(b.toLowerCase());
}
exports.startsWithIgnoreCase = startsWithIgnoreCase;
function isReactText(s) {
    return compareIgnoreCase(s, constants_1.Constants.React);
}
exports.isReactText = isReactText;
function isUseSomething(s) {
    return startsWithIgnoreCase(s, constants_1.Constants.UsePrefix);
}
exports.isUseSomething = isUseSomething;
function isUseRef(s) {
    return compareIgnoreCase(s, constants_1.Constants.UseRef);
}
exports.isUseRef = isUseRef;
function isUseState(s) {
    return compareIgnoreCase(s, constants_1.Constants.UseState);
}
exports.isUseState = isUseState;
//# sourceMappingURL=helper.js.map