import type * as ts from 'typescript/lib/tsserverlibrary';
import { DependExpression, FunctionExpressionLike, HooksReferenceNameType, Ternary } from './types';
import { isUseSomething } from './helper';
export declare function getRangeOfPositionOrRange(positionOrRange: number | ts.TextRange): readonly [number, number | undefined];
export declare function startEndContainsStartEndSkipTrivia(typescript: typeof ts, start: number, end: number, node: ts.Node, file: ts.SourceFile): boolean;
export declare function findTopLevelNodeInSelection(typescript: typeof ts, token: ts.Node, start: number, end: number, file: ts.SourceFile): ts.Node | undefined;
export declare function getGlobalJsxNamespace(typescript: typeof ts, checker: ts.TypeChecker): ts.Symbol | undefined;
export declare function getGlobalJsxElementSymbol(typescript: typeof ts, checker: ts.TypeChecker): ts.Symbol | undefined;
export declare function getGlobalJsxElementType(typescript: typeof ts, checker: ts.TypeChecker): ts.Type | undefined;
export declare function isFunctionComponentLike(node: FunctionExpressionLike, checker: ts.TypeChecker, globalJsxElementType: ts.Type): boolean;
export declare function maybeCustomHooks(typescript: typeof ts, node: FunctionExpressionLike): boolean;
export declare function isInFunctionComponent(typescript: typeof ts, node: ts.Node, checker: ts.TypeChecker): Ternary;
export declare function isInTagNameExpression(typescript: typeof ts, node: ts.Node): boolean;
export declare function isDefinitelyNotSupportedToken(typescript: typeof ts, node: ts.Node): boolean;
export declare function functionExpressionLikeToExpression(typescript: typeof ts, func: FunctionExpressionLike): Exclude<FunctionExpressionLike, ts.FunctionDeclaration>;
export declare function byPassRootDeclaration(typescript: typeof ts, node: ts.Node): ts.Node;
export declare function isConstantDeclarationIfRoot(typescript: typeof ts, node: ts.Node): boolean;
export declare function isTopLevelConstantDeclaration(typescript: typeof ts, declaration: ts.Declaration): boolean;
export declare function isDeclarationAssignedByReactHooks(typescript: typeof ts, declaration: ts.Declaration, pred?: typeof isUseSomething): boolean;
export declare function isDeclarationAssignedByUseRef(typescript: typeof ts, declaration: ts.Declaration): boolean;
export declare function isDeclarationAssignedByUseState(typescript: typeof ts, declaration: ts.Declaration): boolean;
export declare function isDeclarationDefinitelyConstants(typescript: typeof ts, declaration: ts.Declaration): true | undefined;
export interface DepSymbolResolver {
    shouldSymbolDefinitelyBeIgnoreInDeps: (rawSymbol: ts.Symbol) => boolean | undefined;
    alreadyDuplicated: (rawSymbol: ts.Symbol) => boolean;
}
export declare function isInTypeContext(typescript: typeof ts, node: ts.Node): boolean;
export declare function createDepSymbolResolver(typescript: typeof ts, scope: ts.Node, additionalScope: readonly ts.Node[], file: ts.SourceFile, checker: ts.TypeChecker): DepSymbolResolver;
export declare function isFunctionExpressionLike(typescript: typeof ts, v: ts.Node): v is FunctionExpressionLike;
export declare function cloneDeep(typescript: typeof ts, v: ts.Node): ts.Node;
export declare function skipSingleValueDeclaration(typescript: typeof ts, node: ts.Node): ts.Node;
export declare function skipJsxTextToken(typescript: typeof ts, node: ts.Node, file: ts.SourceFile): ts.Node;
export declare function skipJsxExpression(typescript: typeof ts, node: ts.Node): ts.Node;
export declare function isExpression(typescript: typeof ts, node: ts.Node): node is ts.Expression;
export declare function wrapIntoJsxExpressionIfNeed(typescript: typeof ts, node: ts.Node, newNode: ts.Expression): ts.Expression;
export declare function skipParenthesesUp(typescript: typeof ts, node: ts.Node): ts.Node;
export declare function isReactHooks(typescript: typeof ts, symbol: ts.Symbol, checker: ts.TypeChecker): Ternary.False | Ternary.Maybe | Ternary.True;
export declare function alreadyWrappedOrContainsInReactHooks(typescript: typeof ts, node: ts.Node, checker: ts.TypeChecker): boolean;
export declare function dummyCheckReactHooks(typescript: typeof ts, expression: ts.Expression, pred?: typeof isUseSomething): boolean;
export declare function skipSymbolAlias(typescript: typeof ts, symbol: ts.Symbol, checker: ts.TypeChecker): ts.Symbol;
export declare function getHooksNameReferenceType(typescript: typeof ts, location: ts.Node, checker: ts.TypeChecker, hookName: string, isNewTrasnfromer: boolean): HooksReferenceNameType | undefined;
export declare function createHooksReference(typescript: typeof ts, sourceFile: ts.SourceFile, hooksReference: HooksReferenceNameType | undefined, hooksName: string): [
    ts.Expression,
    ((textChanges: ts.textChanges.ChangeTracker) => void) | undefined
];
export declare function findAndInsertReactImport(typescript: typeof ts, sourceFile: ts.SourceFile, hooksName: string, changeTracker: ts.textChanges.ChangeTracker): void;
export declare function insertNameIntoImportDeclaration(typescript: typeof ts, namedImports: ts.NamedImports, hooksName: string): ts.NamedImports;
export declare function generateImportReactDeclaration(typescript: typeof ts, hooksName: string): ts.ImportDeclaration;
export declare function skipTriviaExpression(typescript: typeof ts, expression: ts.Node): ts.Node;
export declare function dummyDeDuplicateDeps(deps: DependExpression[]): DependExpression[];
export declare function isDependExpression(typescript: typeof ts, expr: ts.Expression): expr is DependExpression;
export declare function shouldExpressionInDeps(typescript: typeof ts, expression: DependExpression, checker: ts.TypeChecker, resolver: DepSymbolResolver): Ternary.False | Ternary.Maybe | Ternary.True;
